#
# spec file for package libvshadow
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define lname	libvshadow1
Name:           libvshadow
Version:        20221030
Release:        bp156.2.6
Summary:        Library to access the Volume Shadow Snapshot (VSS) format
License:        GFDL-1.3-or-later AND LGPL-3.0-or-later
Group:          System/Filesystems
URL:            https://github.com/libyal/libvshadow
Source:         https://github.com/libyal/libvshadow/releases/download/%version/libvshadow-alpha-%version.tar.gz
Source2:        https://github.com/libyal/libvshadow/releases/download/%version/libvshadow-alpha-%version.tar.gz.asc
Source3:        %name.keyring
Source11:       Paper_-_Windowless_Shadow_Snapshots.pdf
Source12:       Slides_-_Windowless_Shadow_Snapshots.pdf
Source13:       Volume_Shadow_Snapshot_VSS_format.pdf
BuildRequires:  %{python_module devel}
BuildRequires:  c_compiler
BuildRequires:  pkg-config
BuildRequires:  python-rpm-macros
BuildRequires:  pkgconfig(fuse)
BuildRequires:  pkgconfig(libbfio) >= 20221025
BuildRequires:  pkgconfig(libcdata) >= 20220115
BuildRequires:  pkgconfig(libcerror) >= 20220101
BuildRequires:  pkgconfig(libcfile) >= 20220106
BuildRequires:  pkgconfig(libclocale) >= 20220107
BuildRequires:  pkgconfig(libcnotify) >= 20220108
BuildRequires:  pkgconfig(libcpath) >= 20220108
BuildRequires:  pkgconfig(libcsplit) >= 20220109
BuildRequires:  pkgconfig(libcthreads) >= 20220102
BuildRequires:  pkgconfig(libfdatetime) >= 20220112
BuildRequires:  pkgconfig(libfguid) >= 20220113
BuildRequires:  pkgconfig(libuna) >= 20220611
%python_subpackages
# Various notes: https://en.opensuse.org/libyal

%description
Library and tools to access the Volume Shadow Snapshot (VSS) format.
The VSS format is used by Windows, as of Vista, to maintain copies of
data on a storage media volume.

%package -n %{lname}
Summary:        Library and tools to access the Volume Shadow Snapshot (VSS) format
License:        LGPL-3.0-or-later
Group:          System/Libraries

%description -n %{lname}
Library and tools to access the Volume Shadow Snapshot (VSS) format.
The VSS format is used by Windows, as of Vista, to maintain copies of
data on a storage media volume.

%package        tools
Summary:        Tools to access the Volume Shadow Snapshot (VSS) format
License:        LGPL-3.0-or-later
Group:          System/Filesystems

%description    tools
Tools to access the Volume Shadow Snapshot (VSS) format. The VSS
format is used by Windows, as of Vista, to maintain copies of data on
a storage media volume.

%package        devel
Summary:        Development files for %{name}
License:        GFDL-1.3-or-later AND LGPL-3.0-or-later
Group:          Development/Libraries/C and C++
Requires:       %{lname} = %{version}

%description    devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

The package contains %{_docdir}/%{name}:

* OSDFC 2012: Paper - Windowless Shadow Snapshots
* OSDFC 2012: Slides - Windowless Shadow Snapshots

%prep
%autosetup -p1
mkdir doc
cp -av %_sourcedir/*.pdf .

%build
export CFLAGS="%{optflags} -fno-strict-aliasing"
export CXXFLAGS="%{optflags}"
%{python_expand #
echo "V_%version { global: *; };" >v.sym
%configure --disable-static --enable-wide-character-type \
	--enable-python PYTHON_VERSION="%{$python_bin_suffix}" \
	LDFLAGS="-Wl,--version-script=$PWD/v.sym"
grep ' '' ''local' config.log && exit 1
%make_build
%make_install DESTDIR="%_builddir/rt"
%make_build clean
}

%install
mv "%_builddir/rt"/* "%buildroot/"
find "%buildroot" -type f -name "*.la" -delete -print

%post -n %{lname} -p /sbin/ldconfig
%postun -n %{lname} -p /sbin/ldconfig

%files -n %{lname}
%license COPYING*
%{_libdir}/*.so.*

%files -n %name-tools
%{_bindir}/vshadow*
%{_mandir}/man1/*.gz

%files -n %name-devel
%license COPYING*
%doc Paper_-_Windowless_Shadow_Snapshots.pdf
%doc Slides_-_Windowless_Shadow_Snapshots.pdf
%doc Volume_Shadow_Snapshot_*.pdf
%{_includedir}/libvshadow.h
%{_includedir}/libvshadow/
%{_libdir}/*.so
%{_libdir}/pkgconfig/libvshadow.pc
%{_mandir}/man3/*.gz

%files %python_files
%license COPYING*
%python_sitearch/*.so

%changelog
* Sat Nov 26 2022 Jan Engelhardt <jengelh@inai.de>
- Delete system-libs.patch (not needed - system libs are
  autodetected)
* Mon Oct 31 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 20221030
  * No changelog was provided
* Mon Aug  8 2022 Jan Engelhardt <jengelh@inai.de>
- Add forced symvers
* Mon Jan 24 2022 Jan Engelhardt <jengelh@inai.de>
- Enable multipython builds. (Reenables Python2 for Leap 15.)
* Sun Nov 14 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 20211114
  * Recognize up to python3.11 during build
* Sun Nov 14 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 20211113
  * No changelog was provided
* Sun May 16 2021 Jan Engelhardt <jengelh@inai.de>
- Update to snapshot 20210507 (9f06d799)
  * No changelog was provided
- Add system-libs.patch
* Thu Dec 24 2020 Greg Freemyer <Greg.Freemyer@gmail.com>
- update to v0~20201222
  * Changes for large amount of block descriptors
  * Worked on format support
  * Worked on Python bindings
  * Code clean up
* Thu Apr 30 2020 Greg Freemyer <Greg.Freemyer@gmail.com>
- remove python2 submodule
* Tue Apr  2 2019 Greg Freemyer <Greg.Freemyer@gmail.com>
- update to v0~20190323
  * Fixed bug for over 30 snapshots in place
  * Worked on mount tool
* Mon Nov  6 2017 Greg.Freemyer@gmail.com
- add python3 binding subpackage
* Wed Oct  4 2017 Greg.Freemyer@gmail.com
- rename python-libvshadow to python2-libshadow as expected by singlespec
- remove Provides pyvshadow as it is not versioned
* Mon Oct  2 2017 Greg.Freemyer@gmail.com
- update to v0~20170902
  * applied 2017 update
  * worked on tests
* Thu Feb 16 2017 Greg.Freemyer@gmail.com
- update to v0~20161111
- rename Volume_Shadow_Snapshot_VSS_format.pdf to meet new OBS naming rules
- clean up BuildRequires
* Mon Jan 25 2016 Greg.Freemyer@gmail.com
- update to v0~20160110
  * worked on Python 3 support
  * worked on win2k3 format support
  * introduced new function has_in_volume_data
* Thu Jan  8 2015 Greg.Freemyer@gmail.com
- update to v0~20150106
  * 2015 update - minimal changes
- remove ifdef macros around buildrequires
  * The ifdefs are no longer needed now that all of libyal is in security:forensics
- update BuildRequires based on new packages in OBS
* Thu Dec 11 2014 Greg.Freemyer@gmail.com
- update to v0~20141023
  * bug fix in Python-bindings
  * update man page / info page
- update URL to point to new home on github
- update Source: field to a full URL referring to github
- delete DL-URL comment
- add several BuildRequires to use libyal packages from OBS
* Wed Aug 20 2014 Greg.Freemyer@gmail.com
- add "Requires:  %%lname = %%version" to tools sub-project
- add "Provice:  pyvshadow" to match upstream requires
* Wed Aug 13 2014 Greg.Freemyer@gmail.com
- update to v0~20140731
  * updated dependencies
  * worked on Python bindings
  * worked on setup.py
  * changed return value check of libvshadow_store_read_buffer to allow for
  on read size valid read count values
  * subtle bug fix where python file-like object returns an int object
  instead of long object
  * improved error reporting
* Thu Oct  3 2013 Greg.Freemyer@gmail.com
- update to 0~20131003
  * Primarily Windows related improvements
- add libcthread as a standalone BuildRequires
- update BuildRequires for post 13.1 builds
* Fri Aug  2 2013 Greg.Freemyer@gmail.com
- add version levels to BuildRequires to due to a build failure with older libyal packages
* Sat Jul 27 2013 Greg.Freemyer@gmail.com
- update to 0~20130723
  * Changes for stand-alone libbfio build
  * remove unnecessary restriction in library include headers
  * updated dependencies
  * worked on multi-threading support
  * added libvshadow_volume_get_store_identifier function
  * added libcthreads
  * changes to read block descriptors on demand improves vshadowinfo preformance
  * fixes for multiple open/close on the same volume object
  * fixed issue in read buffer due to recent changes
  * added store read from file IO handle function
  * vshadowmount small changes
  * worked on tests
  * worked on vshadowmount Dokan support
- Added buildrequires for gcc
- Use factory libyal packages if possible
- Add BuildRequires for fuse-devel.  Required for vshadowmount in libvshadow-tools to work correctly.
* Wed Apr 17 2013 Greg.Freemyer@gmail.com
- update to 0~20130413
- make specfile more consistent with the other Joachim Metz packages in openSUSE
  * change version from 0.0.0~%%{timestamp} to 0~%%{timestamp}
  * move developer docs to devel package
  * add BuildRequires for the internally provided libs
- add Volume_Shadow_Snapshot_(VSS)_format.pdf to devel package
* Wed Mar 27 2013 Greg.Freemyer@gmail.com
- initial package 0~20130304
